==> homerun-1.2.2.tar.xz: homerun-1.2.2/kicker/package/metadata.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Homerun Kicker
Name[ca]=Kicker Homerun
Name[da]=Homerun-kicker
Name[de]=Homerun-Kicker
Name[el]=Homerun Kicker
Name[es]=Homerun Kicker
Name[fi]=Homerun Kicker
Name[fr]=Lanceur de Homerun
Name[hu]=Homerun kirúgó
Name[it]=Kicker di Homerun
Name[ko]=Homerun Kicker
Name[nl]=Programmastarter Homerun
Name[pt]=Homerun Kicker
Name[pt_BR]=Homerun Kicker
Name[sk]=Spúšťač Homerun
Name[sl]=Majhen zaganjalnik Homerun
Name[sv]=Homerun startprogram
Name[tr]=Homerun Kicker
Name[uk]=Меню Homerun
Name[x-test]=xxHomerun Kickerxx
Comment=Non-fullscreen version of Homerun
Comment[ca]=Versió de Homerun sense pantalla completa
Comment[da]=Ikke-fuldskærm version af Homerun
Comment[de]=Nicht-Vollbildversion von Homerun
Comment[el]=Έκδοση του Homerun χωρίς πλήρη οθόνη
Comment[es]=Versión no a pantalla completa de Homerun
Comment[fi]=Homerunin versio, joka ei vie koko näyttöä
Comment[fr]=Version de Homerun non plein-écran
Comment[hu]=A Homerun nem teljes képernyős verziója
Comment[it]=Versione di Homerun a schermo ridotto
Comment[ko]=Homerun의 창 모드 버전
Comment[nl]=Versie van Homerun zonder volledig scherm
Comment[pt]=Versão em ecrã não-completo do Homerun
Comment[pt_BR]=Versão do Homerun em janela
Comment[sk]=Neplnoobrazovková verzia Homerun
Comment[sl]=Različica Homeruna, ki ni celozaslonska
Comment[sv]=Version av Homerun utan fullskärmsläge
Comment[tr]=Homerun'ın tam ekran olmayan sürümü
Comment[uk]=Неповноекранна версія Homerun
Comment[x-test]=xxNon-fullscreen version of Homerunxx

Icon=homerun
Type=Service
X-KDE-ServiceTypes=Plasma/Applet,Plasma/PopupApplet

X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-KDE-PluginInfo-Author=Homerun Developers
X-KDE-PluginInfo-Name=org.kde.homerun-kicker
X-KDE-PluginInfo-Version=@HOMERUN_VERSION@
X-KDE-PluginInfo-Website=http://userbase.kde.org/Homerun
X-KDE-PluginInfo-Category=Application Launchers
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL v2+
X-KDE-PluginInfo-EnabledByDefault=true

==> homerun-1.2.5.tar.xz: homerun-1.2.5/kicker/package/metadata.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Homerun Kicker
Name[ca]=Kicker Homerun
Name[ca@valencia]=Kicker Homerun
Name[da]=Homerun-kicker
Name[de]=Homerun-Kicker
Name[el]=Homerun Kicker
Name[es]=Homerun Kicker
Name[fi]=Homerun Kicker
Name[fr]=Lanceur de Homerun
Name[hu]=Homerun kirúgó
Name[it]=Kicker di Homerun
Name[ko]=Homerun Kicker
Name[nl]=Programmastarter Homerun
Name[pl]=Program uruchamiający Homerun
Name[pt]=Homerun Kicker
Name[pt_BR]=Homerun Kicker
Name[sk]=Spúšťač Homerun
Name[sl]=Majhen zaganjalnik Homerun
Name[sv]=Homerun startprogram
Name[tr]=Homerun Kicker
Name[uk]=Меню Homerun
Name[x-test]=xxHomerun Kickerxx
Comment=Non-fullscreen version of Homerun
Comment[ca]=Versió de Homerun sense pantalla completa
Comment[ca@valencia]=Versió de Homerun sense pantalla completa
Comment[da]=Ikke-fuldskærm version af Homerun
Comment[de]=Nicht-Vollbildversion von Homerun
Comment[el]=Έκδοση του Homerun χωρίς πλήρη οθόνη
Comment[es]=Versión no a pantalla completa de Homerun
Comment[fi]=Homerunin versio, joka ei vie koko näyttöä
Comment[fr]=Version de Homerun non plein-écran
Comment[hu]=A Homerun nem teljes képernyős verziója
Comment[it]=Versione di Homerun a schermo ridotto
Comment[ko]=Homerun의 창 모드 버전
Comment[nl]=Versie van Homerun zonder volledig scherm
Comment[pl]=Wersja niepełnoekranowa Homerun
Comment[pt]=Versão em ecrã não-completo do Homerun
Comment[pt_BR]=Versão do Homerun em janela
Comment[sk]=Neplnoobrazovková verzia Homerun
Comment[sl]=Različica Homeruna, ki ni celozaslonska
Comment[sv]=Version av Homerun utan fullskärmsläge
Comment[tr]=Homerun'ın tam ekran olmayan sürümü
Comment[uk]=Неповноекранна версія Homerun
Comment[x-test]=xxNon-fullscreen version of Homerunxx

Icon=homerun
Type=Service
X-KDE-ServiceTypes=Plasma/Applet,Plasma/PopupApplet

X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-KDE-PluginInfo-Author=Homerun Developers
X-KDE-PluginInfo-Name=org.kde.homerun-kicker
X-KDE-PluginInfo-Version=@HOMERUN_VERSION@
X-KDE-PluginInfo-Website=http://userbase.kde.org/Homerun
X-KDE-PluginInfo-Category=Application Launchers
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=GPL v2+
X-KDE-PluginInfo-EnabledByDefault=true
